summaryrefslogtreecommitdiff
path: root/libavcodec
diff options
context:
space:
mode:
authorDiego Biurrun <diego@biurrun.de>2011-10-30 17:59:01 +0100
committerDiego Biurrun <diego@biurrun.de>2011-11-02 10:42:54 +0100
commit20566eb0f0e3b0f538bcf68fca42e67afaa0dec6 (patch)
treed06fd70d43d1d8ad060f36c02861579ffdca5bfd /libavcodec
parent124e28847b95a70724399c8473dd778b5c4c8ffc (diff)
Replace outdated references to ffmpeg tool with avconv.
Diffstat (limited to 'libavcodec')
-rw-r--r--libavcodec/adxenc.c2
-rw-r--r--libavcodec/libxvidff.c6
2 files changed, 4 insertions, 4 deletions
diff --git a/libavcodec/adxenc.c b/libavcodec/adxenc.c
index 296ccbd58a..61ba07a35d 100644
--- a/libavcodec/adxenc.c
+++ b/libavcodec/adxenc.c
@@ -145,7 +145,7 @@ static int adx_encode_frame(AVCodecContext *avctx,
/*
input data size =
- ffmpeg.c: do_audio_out()
+ avconv.c:do_audio_out()
frame_bytes = enc->frame_size * 2 * enc->channels;
*/
diff --git a/libavcodec/libxvidff.c b/libavcodec/libxvidff.c
index 526969066d..d0f4ed39be 100644
--- a/libavcodec/libxvidff.c
+++ b/libavcodec/libxvidff.c
@@ -137,7 +137,7 @@ static av_cold int xvid_encode_init(AVCodecContext *avctx) {
xvid_enc_create_t xvid_enc_create;
xvid_enc_plugin_t plugins[7];
/* Bring in VOP flags from ffmpeg command-line */
x->vop_flags = XVID_VOP_HALFPEL; /* Bare minimum quality */
if( xvid_flags & CODEC_FLAG_4MV )
x->vop_flags |= XVID_VOP_INTER4V; /* Level 3 */
@@ -191,7 +191,7 @@ static av_cold int xvid_encode_init(AVCodecContext *avctx) {
break;
}
/* Bring in VOL flags from ffmpeg command-line */
x->vol_flags = 0;
if( xvid_flags & CODEC_FLAG_GMC ) {
x->vol_flags |= XVID_VOL_GMC;
@@ -669,7 +669,7 @@ static int xvid_ff_2pass_create(xvid_plg_create_t * param,
/* This is because we can safely prevent a buffer overflow */
log[0] = 0;
snprintf(log, BUFFER_REMAINING(log),
- "# ffmpeg 2-pass log file, using xvid codec\n");
+ "# avconv 2-pass log file, using xvid codec\n");
snprintf(BUFFER_CAT(log), BUFFER_REMAINING(log),
"# Do not modify. libxvidcore version: %d.%d.%d\n\n",
XVID_VERSION_MAJOR(XVID_VERSION),
@@ -137,7 +137,7 @@ static av_cold int xvid_encode_init(AVCodecContext *avctx) {
xvid_enc_create_t xvid_enc_create;
xvid_enc_plugin_t plugins[7];
- /* Bring in VOP flags from ffmpeg command-line */
+ /* Bring in VOP flags from avconv command-line */
x->vop_flags = XVID_VOP_HALFPEL; /* Bare minimum quality */
if( xvid_flags & CODEC_FLAG_4MV )
@@ -191,7 +191,7 @@ static av_cold int xvid_encode_init(AVCodecContext *avctx) {
break;
}
- /* Bring in VOL flags from ffmpeg command-line */
+ /* Bring in VOL flags from avconv command-line */
x->vol_flags = 0;
if( xvid_flags & CODEC_FLAG_GMC ) {